@@ -16,7 +16,7 @@
 //
 //    You should have received a copy of the GNU General Public License
 //    along with this program; if not, write to the Free Software
-//    Foundation, Inc., 51 Franklin Steet, Fifth Floor, Cambridge, MA 02110-1301, USA.
+//    Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA.
 //
 //////////////////////////////////////////////////////////////////////////////
 
@@ -81,12 +81,13 @@ extern "C"
 
 // Include files for libKipi.
 
-#include <libkipi/version.h>
 #include <libkipi/imageinfo.h>
 
 // Local includes
 
+#include "pluginsversion.h"
 #include "acquireimagedialog.h"
+#include "acquireimagedialog.moc"
 
 namespace KIPIAcquireImagesPlugin
 {
@@ -115,23 +116,20 @@ AcquireImageDialog::AcquireImageDialog( KIPI::Interface* interface, QWidget *par
     slotImageFormatChanged(m_imagesFormat->currentText());
     page_setupImageOptions->setFocus();
     resize( 600, 400 );
-    
+
     // About data and help button.
-    
-    KAboutData* about = new KAboutData("kipiplugins",
-                                       I18N_NOOP("Acquire images"), 
-                                       kipi_version,
-                                       I18N_NOOP("A Kipi plugin to acquire images"),
-                                       KAboutData::License_GPL,
-                                       "(c) 2003-2004, Gilles Caulier", 
-                                       0,
-                                       "http://extragear.kde.org/apps/kipi");
-    
-    about->addAuthor("Gilles Caulier", I18N_NOOP("Author and maintainer"),
-                     "caulier dot gilles at free.fr");
+
+    m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("Acquire images"),
+                                           NULL,
+                                           KAboutData::License_GPL,
+                                           I18N_NOOP("A Kipi plugin to acquire images"),
+                                           "(c) 2003-2004, Gilles Caulier");
+
+    m_about->addAuthor("Gilles Caulier", I18N_NOOP("Author and maintainer"),
+                       "caulier dot gilles at gmail dot com");
 
     m_helpButton = actionButton( Help );
-    KHelpMenu* helpMenu = new KHelpMenu(this, about, false);
+    KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
     helpMenu->menu()->insertItem(i18n("Acquire Images Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
     m_helpButton->setPopup( helpMenu->menu() );
@@ -142,6 +140,7 @@ AcquireImageDialog::AcquireImageDialog( KIPI::Interface* interface, QWidget *par
 
 AcquireImageDialog::~AcquireImageDialog()
 {
+    delete m_about;
 }
 
 
@@ -446,7 +445,7 @@ void AcquireImageDialog::slotAlbumSelected( const KURL &url )
 
     writeSettings();
 
-    // Get all scanned image informations.
+    // Get all scanned image information.
     QString imageFormat = m_imagesFormat->currentText();
     int imageCompression = m_imageCompression->value();
     QString Commentsimg = m_CommentsEdit->text();
@@ -610,4 +609,3 @@ bool AcquireImageDialog::QImageToTiff(const QImage& image, const QString& dst)
 
 }  // NameSpace KIPIAcquireImagesPlugin
 
-#include "acquireimagedialog.moc"
