@@ -4,7 +4,7 @@
  * Date  : 2005-07-07
  * Description :
  *
- * Copyright 2005 by Vardhman Jain
+ * Copyright 2005 by Vardhman Jain <vardhman @ gmail.com>
 
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -38,6 +38,7 @@
 #include <qdom.h>
 #include <cstring>
 #include <cstdio>
+#include <cstdlib>
 
 #include <string>
 #include "flickritem.h"
@@ -157,8 +158,8 @@ namespace KIPIFlickrExportPlugin
 		QString queryStr=headers.join("&");
 		const QString completeUrl=url+queryStr;
 		KApplication::kApplication()->invokeBrowser(completeUrl);
-		int valueOk=KMessageBox::questionYesNo(0, i18n("Please Follow through the instructions in the browser window and "
-              "return back to press ok if you are authenticated or press No"), i18n("Flickr::Kipi Plugin:Web Authorization")); 
+		int valueOk=KMessageBox::questionYesNo(0, i18n("Please follow the instructions in the browser window and "
+              "return to press Yes if you were able to log in or No to cancel the export"), i18n("Flickr:Web Authorization"));
 
 					if(valueOk==KMessageBox::Yes){
 						getToken(); 
@@ -299,7 +300,15 @@ namespace KIPIFlickrExportPlugin
 		form.addPair("is_friend",isfriend);
 		headers.append("is_friend="+ isfriend);
 
-		QString tags=info.tags.join(" ");
+		QStringList taglist;
+		for(QStringList::Iterator iter = info.tags.begin(); iter != info.tags.end(); iter++) {
+			if((*iter).find(' ') != -1) {
+				taglist.append('"' + *iter + '"');
+			} else {
+				taglist.append(*iter);
+				}
+		}
+		QString tags=taglist.join(" ");
 		if(tags.length()>0){	
 			form.addPair("tags",tags);
 			headers.append("tags="+ tags);
