@@ -4,7 +4,7 @@
  * Date  : 2004-11-30
  * Description :
  *
- * Copyright 2004 by Renchi Raju
+ * Copyright 2004 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
 
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -34,6 +34,10 @@
 #include <cstring>
 #include <cstdio>
 
+// LibKExiv2 includes. 
+
+#include <libkexiv2/kexiv2.h>
+
 #include "galleryitem.h"
 #include "gallerympform.h"
 #include "gallerytalker.h"
@@ -53,6 +57,7 @@ GalleryTalker::~GalleryTalker()
 }
 
 bool GalleryTalker::s_using_gallery2 = true;
+QString GalleryTalker::s_authToken = "";
 
 bool GalleryTalker::loggedIn() const
 {
@@ -67,7 +72,7 @@ void GalleryTalker::login( const KURL& url, const QString& name,
     GalleryMPForm form;
 
     form.addPair("cmd",              "login");
-    form.addPair("protocol_version", "2.3");
+    form.addPair("protocol_version", "2.11");
     form.addPair("uname",            name);
     form.addPair("password",         passwd);
     form.finish();
@@ -95,7 +100,7 @@ void GalleryTalker::listAlbums()
       task = "fetch-albums-prune";
 
     form.addPair("cmd",              task);
-    form.addPair("protocol_version", "2.3");
+    form.addPair("protocol_version", "2.11");
     form.finish();
 
     KIO::TransferJob* job = KIO::http_post(m_url, form.formData(), false);
@@ -124,7 +129,7 @@ void GalleryTalker::listPhotos( const QString& albumName )
     GalleryMPForm form;
 
     form.addPair("cmd",              "fetch-album-images");
-    form.addPair("protocol_version", "2.3");
+    form.addPair("protocol_version", "2.11");
     form.addPair("set_albumName",    albumName);
     form.finish();
 
@@ -157,7 +162,7 @@ void GalleryTalker::createAlbum( const QString& parentAlbumName,
     GalleryMPForm form;
 
     form.addPair("cmd", "new-album");
-    form.addPair("protocol_version", "2.3");
+    form.addPair("protocol_version", "2.11");
     form.addPair("set_albumName", parentAlbumName);
     if (!albumName.isEmpty())
         form.addPair("newAlbumName", albumName);
@@ -199,7 +204,7 @@ bool GalleryTalker::addPhoto( const QString& albumName,
     GalleryMPForm form;
 
     form.addPair("cmd", "add-item");
-    form.addPair("protocol_version", "2.3");
+    form.addPair("protocol_version", "2.11");
     form.addPair("set_albumName", albumName);
 
     if (!caption.isEmpty())
@@ -214,6 +219,15 @@ bool GalleryTalker::addPhoto( const QString& albumName,
             image = image.smoothScale(maxDim, maxDim, QImage::ScaleMin);
             path = locateLocal("tmp", KURL(photoPath).filename());
             image.save(path, QImageIO::imageFormat(photoPath));
+
+            if ("JPEG" == QString(QImageIO::imageFormat(photoPath)).upper())
+            {
+              KExiv2Iface::KExiv2 exiv2;
+              if (exiv2.load(photoPath))
+              {
+                exiv2.save(path);
+              }
+            }
             kdDebug() << "Resizing and saving to temp file: "
                       << path << endl;
         }
@@ -304,7 +318,7 @@ void GalleryTalker::slotResult(KIO::Job *job)
         m_cookie = "Cookie:";
         for (QStringList::Iterator it = cookielist.begin(); it != cookielist.end(); ++it)
         {
-            QRegExp rx("^Set-Cookie: ([^;]+)");
+            QRegExp rx("^Set-Cookie: ([^;]+=[^;]+)");
             if (rx.search(*it) > -1)
                 m_cookie += " " + rx.cap(1) + ";";
         }
@@ -319,6 +333,8 @@ void GalleryTalker::parseResponseLogin(const QByteArray &data)
     QString     line;
     bool foundResponse = false;
 
+    m_loggedIn = false;
+    
     while (!ts.atEnd())
     {
         line = ts.readLine();
@@ -332,10 +348,14 @@ void GalleryTalker::parseResponseLogin(const QByteArray &data)
             QStringList strlist = QStringList::split("=", line);
             if (strlist.count() == 2)
             {
-                m_loggedIn = (strlist[0] == "status") &&
-                             (strlist[1] == "0");
-                if (m_loggedIn)
-                    break;
+                if (("status" == strlist[0]) && ("0" == strlist[1]))
+                {
+                  m_loggedIn = true;
+                }
+                else if ("auth_token" == strlist[0])
+                {
+                  s_authToken = strlist[1];
+                }
             }
         }
     }
@@ -433,6 +453,10 @@ void GalleryTalker::parseResponseListAlbums(const QByteArray &data)
                     if (iter != albumList.end())
                         (*iter).create_sub = (value == "true");
                 }
+                else if (key == "auth_token")
+                {
+                  s_authToken = value;
+                }
             }
         }
     }
