@@ -1,10 +1,10 @@
 /* ============================================================
- * Authors: Gilles Caulier <caulier dot gilles at kdemail dot net>
+ * Authors: Gilles Caulier <caulier dot gilles at gmail dot com>
  * Date   : 2006-05-16
  * Description : a plugin to synchronize pictures with 
  *               a GPS device.
  *
- * Copyright 2006 by Gilles Caulier
+ * Copyright 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -27,6 +27,7 @@
 #include <libkipi/plugin.h>
 
 class KActionMenu;
+class KAction;
 
 class Plugin_GPSSync : public KIPI::Plugin
 {
@@ -44,6 +45,8 @@ protected slots:
     void slotGPSSync();
     void slotGPSEdit();
     void slotGPSRemove();
+    void slotKMLGenerate();
+    void slotKMLExport();
 
 private:
 
@@ -52,6 +55,7 @@ private:
 private:
 
     KActionMenu     *m_action_geolocalization;
+    KAction         *m_actionKMLExport;
 
     KIPI::Interface *m_interface;
 };
