@@ -1,17 +1,18 @@
 /* ============================================================
- * Authors: Renchi Raju <renchi@pooh.tam.uiuc.edu>
- *          Gilles Caulier <caulier dot gilles at kdemail dot net>
- * Date   : 2003-10-14
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2003-10-14
  * Description : batch image rotation
- * 
- * Copyright 2003-2005 by Renchi Raju
- * Copyright 2006 by Gilles Caulier
+ *
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
+ * either version 2, or (at your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -112,7 +113,7 @@ bool ImageRotate::rotate(const QString& src, RotateAction angle, const QString&
 
 bool ImageRotate::rotateJPEG(const QString& src, const QString& dest, RotateAction angle, QString& err)
 {
-    Matrix &transform=Matrix::none;
+    Matrix transform=Matrix::none;
 
     switch(angle)
     {
