@@ -1,23 +1,24 @@
 /* ============================================================
- * Authors: Renchi Raju <renchi@pooh.tam.uiuc.edu>
- *          Gilles Caulier <caulier dot gilles at kdemail dot net>
- * Date   : 2003-09-26
- * Description : JPEG loss less operations plugin
  *
- * Copyright 2003-2005 by Renchi Raju & Gilles Caulier
- * Copyright 2006 by Gilles Caulier
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2003-09-26
+ * Description : loss less images transformations plugin.
+ *
+ * Copyright (C) 2003-2005 by Renchi Raju & Gilles Caulier <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
+ * either version 2, or (at your option) any later version.
+ * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * ============================================================ */
 
 // C++ includes.
@@ -40,7 +41,7 @@
 #include <kmessagebox.h>
 #include <kapplication.h>
 
-// Lib KIPI includes.
+// LibKipi includes.
 
 #include <libkipi/batchprogressdialog.h>
 #include <libkipi/interface.h>
@@ -68,6 +69,7 @@ Plugin_JPEGLossless::Plugin_JPEGLossless(QObject *parent, const char*, const QSt
     m_action_FlipImage         = 0;
     m_progressDlg              = 0;
     m_thread                   = 0;
+    m_failed                   = false;
 
     kdDebug( 51001 ) << "Plugin_JPEGLossless plugin loaded" << endl;
 }
@@ -77,71 +79,60 @@ void Plugin_JPEGLossless::setup( QWidget* widget )
     KIPI::Plugin::setup( widget );
 
     m_action_AutoExif = new KAction(i18n("Auto Rotate/Flip Using Exif Information"),
-                                    0,
-                                    0,
-                                    this,
-                                    SLOT(slotRotate()),
-                                    actionCollection(),
-                                    "rotate_exif");    
-
+                                  0, 0,
+                                  this,
+                                  SLOT(slotRotate()),
+                                  actionCollection(),
+                                  "rotate_exif");    
 
     m_action_RotateImage = new KActionMenu(i18n("Rotate"),
-                           "rotate_cw",
-                           actionCollection(),
-                           "jpeglossless_rotate");
+                                  "rotate_cw",
+                                  actionCollection(),
+                                  "jpeglossless_rotate");
 
-    m_action_RotateImage->insert( new KAction(i18n("90 Degrees"),
-                                  0,
-                                  CTRL+Key_9,
+    m_action_RotateImage->insert( new KAction(i18n("Left"),
+                                  "rotate_ccw",
+                                  SHIFT+CTRL+Key_Left,
                                   this,
                                   SLOT(slotRotate()),
                                   actionCollection(),
-                                  "rotate_90") );
-
-    m_action_RotateImage->insert( new KAction(i18n("180 Degrees"),
-                                  0,
-                                  CTRL+Key_8,
+                                  "rotate_ccw") );
+    m_action_RotateImage->insert( new KAction(i18n("Right"),
+                                  "rotate_cw",
+                                  SHIFT+CTRL+Key_Right,
                                   this,
                                   SLOT(slotRotate()),
                                   actionCollection(),
-                                  "rotate_180") );
-
-    m_action_RotateImage->insert( new KAction(i18n("270 Degrees"),
-                                  0,
-                                  CTRL+Key_7,
-                                  this,
-                                  SLOT(slotRotate()),
-                                  actionCollection(),
-                                  "rotate_270") );
+                                  "rotate_cw") );
 
     m_action_FlipImage = new KActionMenu(i18n("Flip"),
-                             "flip",
-                             actionCollection(),
-                             "jpeglossless_flip");
+                                  "flip",
+                                  actionCollection(),
+                                  "jpeglossless_flip");
 
     m_action_FlipImage->insert( new KAction(i18n("Horizontally"),
-                                0,
-                                CTRL+Key_Asterisk,
-                                this,
-                                SLOT(slotFlip()),
-                                actionCollection(),
-                                "flip_horizontal") );
+                                  0,
+                                  CTRL+Key_Asterisk,
+                                  this,
+                                  SLOT(slotFlip()),
+                                  actionCollection(),
+                                  "flip_horizontal") );
 
     m_action_FlipImage->insert( new KAction(i18n("Vertically"),
-                                0,
-                                CTRL+Key_Slash,
-                                this,
-                                SLOT(slotFlip()),
-                                actionCollection(),
-                                "flip_vertical") );
+                                  0,
+                                  CTRL+Key_Slash,
+                                  this,
+                                  SLOT(slotFlip()),
+                                  actionCollection(),
+                                  "flip_vertical") );
 
     m_action_Convert2GrayScale = new KAction(i18n("Convert to Black && White"),
-                                             "grayscaleconvert",
-                                             0,
-                                             this,
-                                             SLOT(slotConvert2GrayScale()),
-                                             actionCollection(),
-                                             "jpeglossless_convert2grayscale");
+                                  "grayscaleconvert",
+                                  0,
+                                  this,
+                                  SLOT(slotConvert2GrayScale()),
+                                  actionCollection(),
+                                  "jpeglossless_convert2grayscale");
 
     addAction( m_action_AutoExif );
     addAction( m_action_RotateImage );
@@ -149,18 +140,18 @@ void Plugin_JPEGLossless::setup( QWidget* widget )
     addAction( m_action_Convert2GrayScale );
 
     KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>( parent() );
-    
+
     if ( !interface ) 
     {
         kdError( 51000 ) << "Kipi interface is null!" << endl;
         return;
     }
-           
+
     m_action_AutoExif->setEnabled( false );
     m_action_RotateImage->setEnabled( false );
     m_action_FlipImage->setEnabled( false );
     m_action_Convert2GrayScale->setEnabled( false );
-    
+
     m_thread = new KIPIJPEGLossLessPlugin::ActionThread(interface, this);
 
     connect( interface, SIGNAL( selectionChanged( bool ) ),
@@ -200,7 +191,7 @@ void Plugin_JPEGLossless::slotFlip()
     else if (from == "flip_vertical") 
     {
         m_thread->flip(items, KIPIJPEGLossLessPlugin::FlipVertical);
-        title = i18n("verticaly");
+        title = i18n("vertically");
         proceed = true;
     }
     else 
@@ -212,13 +203,17 @@ void Plugin_JPEGLossless::slotFlip()
     if (!proceed) return;
     m_total   = items.count();
     m_current = 0;
+    m_failed  = false;
 
     if (m_progressDlg) 
+    {
         delete m_progressDlg;
-    
+        m_progressDlg = 0;
+    }
+
     m_progressDlg = new KIPI::BatchProgressDialog(kapp->activeWindow(), 
                         i18n("Flip images %1").arg(title));
-    
+
     connect(m_progressDlg, SIGNAL(cancelClicked()),
             this, SLOT(slotCancel()));
 
@@ -237,22 +232,16 @@ void Plugin_JPEGLossless::slotRotate()
     QString title;
     bool proceed = false;
 
-    if (from == "rotate_90") 
+    if (from == "rotate_cw") 
     {
         m_thread->rotate(items, KIPIJPEGLossLessPlugin::Rot90);
-        title = i18n("to 90 degrees");
+        title = i18n("right (clockwise)");
         proceed = true;
     }
-    else if (from == "rotate_180") 
-    {
-        m_thread->rotate(items, KIPIJPEGLossLessPlugin::Rot180);
-        title = i18n("to 180 degrees");
-        proceed = true;
-    }
-    else if (from == "rotate_270") 
+    else if (from == "rotate_ccw") 
     {
         m_thread->rotate(items, KIPIJPEGLossLessPlugin::Rot270);
-        title = i18n("to 270 degrees");
+        title = i18n("left (counterclockwise)");
         proceed = true;
     }
     else if (from == "rotate_exif") 
@@ -270,9 +259,13 @@ void Plugin_JPEGLossless::slotRotate()
     if (!proceed) return;
     m_total   = items.count();
     m_current = 0;
+    m_failed  = false;
 
     if (m_progressDlg) 
+    {
         delete m_progressDlg;
+        m_progressDlg = 0;
+    }
 
     m_progressDlg = new KIPI::BatchProgressDialog(kapp->activeWindow(), 
                         i18n("Rotate images %1").arg(title));
@@ -299,9 +292,13 @@ void Plugin_JPEGLossless::slotConvert2GrayScale()
 
     m_total   = items.count();
     m_current = 0;
+    m_failed  = false;
 
     if (m_progressDlg) 
+    {
         delete m_progressDlg;
+        m_progressDlg = 0;
+    }
 
     m_progressDlg = new KIPI::BatchProgressDialog(kapp->activeWindow(), 
                         i18n("Convert images to black & white"));
@@ -321,13 +318,13 @@ void Plugin_JPEGLossless::slotCancel()
     m_thread->cancel();
 
     KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>( parent() );
-    
+
     if ( !interface ) 
     {
         kdError( 51000 ) << "Kipi interface is null!" << endl;
         return;
     }
-    
+
     interface->refreshImages( m_images );
 }
 
@@ -359,7 +356,7 @@ void Plugin_JPEGLossless::customEvent(QCustomEvent *event)
                 text = i18n("Converting to Black & White \"%1\"").arg(d->fileName.section('/', -1));
                 break;
             }
-            default: 
+            default:
             {
                 kdWarning( 51000 ) << "KIPIJPEGLossLessPlugin: Unknown event" << endl;
             }
@@ -367,10 +364,12 @@ void Plugin_JPEGLossless::customEvent(QCustomEvent *event)
 
         m_progressDlg->addedAction(text, KIPI::StartingMessage);
     }
-    else 
+    else
     {
         if (!d->success) 
         {
+            m_failed = true;
+
             switch (d->action) 
             {
                 case(KIPIJPEGLossLessPlugin::Rotate): 
@@ -393,10 +392,11 @@ void Plugin_JPEGLossless::customEvent(QCustomEvent *event)
                     kdWarning( 51000 ) << "KIPIJPEGLossLessPlugin: Unknown event" << endl;
                 }
             }
-            
+
             m_progressDlg->addedAction(text, KIPI::WarningMessage);
+
             if (!d->errString.isEmpty())
-                m_progressDlg->addedAction(d->errString, KIPI::WarningMessage);        
+                m_progressDlg->addedAction(d->errString, KIPI::WarningMessage);
         }
         else
         {
@@ -436,17 +436,26 @@ void Plugin_JPEGLossless::customEvent(QCustomEvent *event)
     {
         m_current = 0;
 
+        if (m_failed)
+        {
 #if KDE_VERSION >= 0x30200
-        m_progressDlg->setButtonCancel( KStdGuiItem::close() );
+            m_progressDlg->setButtonCancel( KStdGuiItem::close() );
 #else
-        m_progressDlg->setButtonCancelText( i18n("&Close") );
+            m_progressDlg->setButtonCancelText( i18n("&Close") );
 #endif
 
-        disconnect(m_progressDlg, SIGNAL(cancelClicked()),
-                   this, SLOT(slotCancel()));
+            disconnect(m_progressDlg, SIGNAL(cancelClicked()),
+                    this, SLOT(slotCancel()));
+        }
+        else 
+        {
+            slotCancel();
+            m_progressDlg->close();
+            m_progressDlg = 0;
+        }
 
         KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>( parent() );
-        
+
         if ( !interface ) 
         {
            kdError( 51000 ) << "Kipi interface is null!" << endl;
@@ -462,12 +471,12 @@ KIPI::Category Plugin_JPEGLossless::category( KAction* action ) const
     if (action == m_action_AutoExif)
         return KIPI::IMAGESPLUGIN;
     else if ( action == m_action_RotateImage )
-       return KIPI::IMAGESPLUGIN;       
+       return KIPI::IMAGESPLUGIN;
     else if ( action == m_action_FlipImage )
-       return KIPI::IMAGESPLUGIN;       
+       return KIPI::IMAGESPLUGIN;
     else if ( action == m_action_Convert2GrayScale )
-       return KIPI::IMAGESPLUGIN;       
-           
+       return KIPI::IMAGESPLUGIN;
+
     kdWarning( 51000 ) << "Unrecognized action for plugin category identification" << endl;
     return KIPI::IMAGESPLUGIN; // no warning from compiler, please
 }
@@ -475,13 +484,13 @@ KIPI::Category Plugin_JPEGLossless::category( KAction* action ) const
 KURL::List Plugin_JPEGLossless::images()
 {
     KIPI::Interface* interface = dynamic_cast<KIPI::Interface*>( parent() );
-    
+
     if ( !interface ) 
     {
         kdError( 51000 ) << "Kipi interface is null!" << endl;
         return KURL::List();
     }
-           
+
     KIPI::ImageCollection images = interface->currentSelection();
     if ( !images.isValid() )
         return KURL::List();
