@@ -1,17 +1,18 @@
 /* ============================================================
- * Authors: Renchi Raju <renchi@pooh.tam.uiuc.edu>
- *          Gilles Caulier <caulier dot gilles at kdemail dot net>
- * Date   : 2003-12-03
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2003-12-03
  * Description : misc utils to used in batch process
  * 
- * Copyright 2003-2005 by Renchi Raju
- * Copyright 2006 by Gilles Caulier
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
+ * either version 2, or (at your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -42,9 +43,12 @@ extern "C"
 
 #include <kdebug.h>
 
+// LibKDcraw includes.
+
+#include <libkdcraw/rawfiles.h>
+
 // Local includes.
 
-#include "rawfiles.h"
 #include "utils.h"
 
 namespace KIPIJPEGLossLessPlugin
@@ -58,7 +62,7 @@ bool Utils::isJPEG(const QString& file)
 
 bool Utils::isRAW(const QString& file)
 {
-    QString rawFilesExt(kipi_raw_file_extentions);
+    QString rawFilesExt(raw_file_extentions);
 
     QFileInfo fileInfo(file);
     if (rawFilesExt.upper().contains( fileInfo.extension(false).upper() ))
