@@ -1,9 +1,9 @@
 /* ============================================================
- * Authors: Gilles Caulier <caulier dot gilles at kdemail dot net>
- * Date   : 2006-10-18
+ * Authors     : Gilles Caulier
+ * Date        : 2006-10-18
  * Description : EXIF device settings page.
  * 
- * Copyright 2006 by Gilles Caulier
+ * Copyright 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -38,10 +38,13 @@
 #include <klineedit.h>
 #include <kseparator.h>
 
+// LibKExiv2 includes. 
+
+#include <libkexiv2/kexiv2.h>
+
 // Local includes.
 
 #include "metadatacheckbox.h"
-#include "exiv2iface.h"
 #include "exifdevice.h"
 #include "exifdevice.moc"
 
@@ -463,7 +466,7 @@ EXIFDevice::~EXIFDevice()
 void EXIFDevice::readMetadata(QByteArray& exifData)
 {
     blockSignals(true);
-    KIPIPlugins::Exiv2Iface exiv2Iface;
+    KExiv2Iface::KExiv2 exiv2Iface;
     exiv2Iface.setExif(exifData);
     long int num=1, den=1;
     long     val=0;
@@ -660,7 +663,7 @@ void EXIFDevice::readMetadata(QByteArray& exifData)
 
 void EXIFDevice::applyMetadata(QByteArray& exifData)
 {
-    KIPIPlugins::Exiv2Iface exiv2Iface;
+    KExiv2Iface::KExiv2 exiv2Iface;
     exiv2Iface.setExif(exifData);
     long int num=1, den=1;
 
