@@ -1,9 +1,9 @@
 /* ============================================================
- * Authors: Gilles Caulier <caulier dot gilles at kdemail dot net>
- * Date   : 2006-10-12
+ * Authors     : Gilles Caulier
+ * Date        : 2006-10-12
  * Description : IPTC date and time settings page.
  * 
- * Copyright 2006 by Gilles Caulier
+ * Copyright 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -37,9 +37,12 @@
 #include <kaboutdata.h>
 #include <kseparator.h>
 
+// LibKExiv2 includes. 
+
+#include <libkexiv2/kexiv2.h>
+
 // Local includes.
 
-#include "exiv2iface.h"
 #include "iptcdatetime.h"
 #include "iptcdatetime.moc"
 
@@ -299,7 +302,7 @@ QDateTime IPTCDateTime::getIPTCCreationDate()
 void IPTCDateTime::readMetadata(QByteArray& iptcData)
 {
     blockSignals(true);
-    KIPIPlugins::Exiv2Iface exiv2Iface;
+    KExiv2Iface::KExiv2 exiv2Iface;
     exiv2Iface.setIptc(iptcData);
 
     QDate date;
@@ -429,7 +432,7 @@ void IPTCDateTime::readMetadata(QByteArray& iptcData)
 
 void IPTCDateTime::applyMetadata(QByteArray& exifData, QByteArray& iptcData)
 {
-    KIPIPlugins::Exiv2Iface exiv2Iface;
+    KExiv2Iface::KExiv2 exiv2Iface;
     exiv2Iface.setExif(exifData);
     exiv2Iface.setIptc(iptcData);
 
