@@ -1,9 +1,9 @@
 /* ============================================================
- * Authors: Gilles Caulier <caulier dot gilles at kdemail dot net>
- * Date   : 2006-10-12
+ * Authors     : Gilles Caulier 
+ * Date        : 2006-10-12
  * Description : IPTC status settings page.
  * 
- * Copyright 2006 by Gilles Caulier
+ * Copyright 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -34,11 +34,14 @@
 #include <kapplication.h>
 #include <kaboutdata.h>
 
+// LibKExiv2 includes. 
+
+#include <libkexiv2/kexiv2.h>
+
 // Local includes.
 
 #include "metadatacheckbox.h"
 #include "pluginsversion.h"
-#include "exiv2iface.h"
 #include "iptcstatus.h"
 #include "iptcstatus.moc"
 
@@ -291,7 +294,7 @@ IPTCStatus::~IPTCStatus()
 void IPTCStatus::readMetadata(QByteArray& iptcData)
 {
     blockSignals(true);
-    KIPIPlugins::Exiv2Iface exiv2Iface;
+    KExiv2Iface::KExiv2 exiv2Iface;
     exiv2Iface.setIptc(iptcData);
     QString data;
     int     val;
@@ -408,7 +411,7 @@ void IPTCStatus::readMetadata(QByteArray& iptcData)
 
 void IPTCStatus::applyMetadata(QByteArray& iptcData)
 {
-    KIPIPlugins::Exiv2Iface exiv2Iface;
+    KExiv2Iface::KExiv2 exiv2Iface;
     exiv2Iface.setIptc(iptcData);
 
     if (d->statusCheck->isChecked())
