@@ -2,7 +2,7 @@
 //
 //    KIMG2MPG.CPP
 //
-//    Copyright (C) 2003 Gilles Caulier <caulier dot gilles at free.fr>
+//    Copyright (C) 2003 Gilles Caulier <caulier dot gilles at gmail dot com>
 //
 //    This program is free software; you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 //
 //    You should have received a copy of the GNU General Public License
 //    along with this program; if not, write to the Free Software
-//    Foundation, Inc., 51 Franklin Steet, Fifth Floor, Cambridge, MA 02110-1301, USA.
+//    Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA.
 //
 //////////////////////////////////////////////////////////////////////////////
 
@@ -250,7 +250,7 @@ KImg2mpgData::KImg2mpgData(KIPI::Interface* interface, QWidget *parent, const ch
   "(c) 2003-2004, Gilles Caulier");
 
   m_about->addAuthor("Gilles Caulier", I18N_NOOP("Author"),
-                    "caulier dot gilles at free.fr");
+                    "caulier dot gilles at gmail dot com");
 
   m_about->addAuthor("Angelo Naselli", I18N_NOOP("Maintainer"),
                     "anaselli at linux dot it");
@@ -617,7 +617,7 @@ void KImg2mpgData::slotEncode( void )
   Temp.setNum (BackGroundColor.blue(), 16);
   HexColor = HexColor + Temp.rightJustify(2,'0');
 
-  // This is for debuging output in debug dialog box.
+  // This is for debugging output in debug dialog box.
 
   m_CommandLine = i18n("THE COMMAND LINE IS :\n\n");
   m_CommandLine = m_CommandLine + "images2mpg --with-gui ";
@@ -681,13 +681,21 @@ void KImg2mpgData::slotEncode( void )
   m_CommandLine = m_CommandLine + " -i ";
 
   for (uint i=0 ; i < m_ImagesFilesListBox->count() ; ++i)
-    {
+  {
     QString FileName="";
     ImageItem *pitem = static_cast<ImageItem*>( m_ImagesFilesListBox->item(i) );
     FileName.append (pitem->path());                              // Input images files.
+    if (!QFile::exists(FileName))
+    {
+      KMessageBox::error(this,
+                         i18n("Cannot access to file %1, please check the path is right.").arg(FileName));
+      m_Abort = true;
+      reset();
+      return;
+    }
     *m_Proc << FileName;
     m_CommandLine = m_CommandLine + " \"" + FileName + "\" ";
-    }
+  }
 
   connect(m_Proc, SIGNAL(processExited(KProcess *)),this,
           SLOT(EncodeDone(KProcess*)));
@@ -695,8 +703,9 @@ void KImg2mpgData::slotEncode( void )
   connect(m_Proc, SIGNAL(receivedStderr(KProcess *,char*,int)),this,
           SLOT(readStderr(KProcess*,char*,int)));
 
+  m_Img2mpgPidNum = -1;
   bool result = m_Proc->start(KProcess::NotifyOnExit , KProcess::All);
-
+  
   if(!result)
     {
     QString str = i18n("Cannot start 'images2mpg' bash script : fork failed.");
@@ -990,7 +999,7 @@ void KImg2mpgData::reset()
   {
   m_Encoding = false;
 
-  if (m_Proc)
+  if (m_Proc && m_Img2mpgPidNum > 0)
     {
         ::kill(m_Img2mpgPidNum, SIGKILL);
     }
