@@ -1,23 +1,24 @@
 /* ============================================================
- * Authors: Renchi Raju <renchi@pooh.tam.uiuc.edu>
- *          Gilles Caulier <caulier dot gilles at kdemail dot net>
- * Date  : 2003-10-24
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2003-10-24
  * Description : Raw converter batch dialog
  *
- * Copyright 2003-2005 by Renchi Raju
- * Copyright 2006 by Gilles Caulier
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
+ * either version 2, or (at your option) any later version.
+ * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * ============================================================ */
 
 #ifndef BATCHDIALOG_H
@@ -40,15 +41,20 @@ class QTimer;
 class QWidget;
 class QCustomEvent;
 class QCloseEvent;
+class QGroupBox;
 
 class KListView;
 class KProgress;
 
+namespace KDcrawIface
+{
+class DcrawSettingsWidget;
+}
+
 namespace KIPIRawConverterPlugin
 {
 
 class  ActionThread;
-class  DcrawSettingsWidget;
 class  SaveSettingsWidget;
 struct RawItem;
 
@@ -59,7 +65,7 @@ Q_OBJECT
 
 public:
 
-    BatchDialog(QWidget *parent, const QString& dcrawVersion);
+    BatchDialog(QWidget *parent);
     ~BatchDialog();
 
     void addItems(const QStringList& itemList);
@@ -95,29 +101,31 @@ private slots:
 
 private:
 
-    bool                 m_convertBlink;
+    bool                              m_convertBlink;
 
-    QTimer              *m_blinkConvertTimer;
+    QTimer                           *m_blinkConvertTimer;
 
-    QWidget             *m_page;
+    QWidget                          *m_page;
 
-    QDict<RawItem>       m_itemDict;
+    QDict<RawItem>                    m_itemDict;
 
-    QStringList          m_fileList;
+    QStringList                       m_fileList;
 
-    KProgress           *m_progressBar;
+    QGroupBox                        *m_rawSettingsGroup;
 
-    KListView           *m_listView;
+    KProgress                        *m_progressBar;
 
-    RawItem             *m_currentConvertItem;
+    KListView                        *m_listView;
 
-    ActionThread        *m_thread;
+    RawItem                          *m_currentConvertItem;
 
-    DcrawSettingsWidget *m_decodingSettingsBox;
+    ActionThread                     *m_thread;
 
-    SaveSettingsWidget  *m_saveSettingsBox;
+    SaveSettingsWidget               *m_saveSettingsBox;
 
-    KIPIPlugins::KPAboutData *m_about;
+    KDcrawIface::DcrawSettingsWidget *m_decodingSettingsBox;
+
+    KIPIPlugins::KPAboutData         *m_about;
 };
 
 } // NameSpace KIPIRawConverterPlugin
