@@ -1,33 +1,34 @@
 /* ============================================================
- * Authors: Renchi Raju <renchi@pooh.tam.uiuc.edu>
- *          Gilles Caulier <caulier dot gilles at kdemail dot net>
- * Date   : 2003-10-22
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2003-10-22
  * Description : preview raw file widget used in single convert
  *
- * Copyright 2003-2005 by Renchi Raju
- * Copyright 2006 by Gilles Caulier
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
+ * either version 2, or (at your option) any later version.
+ * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * ============================================================ */
 
 // Qt includes.
 
 #include <qpainter.h>
-#include <qpixmap.h>
+#include <qimage.h>
 #include <qstring.h>
 #include <qevent.h>
 #include <qtimer.h>
-#include <qimage.h>
+#include <qfile.h>
 
 // KDE includes.
 
@@ -52,6 +53,7 @@ public:
     }
 
     QPixmap *pix;
+    QPixmap  preview;
 
     QTimer  *timer;
 
@@ -61,13 +63,17 @@ public:
 };
 
 PreviewWidget::PreviewWidget(QWidget *parent)
-             : QWidget(parent, 0, Qt::WRepaintNoErase)
+             : QFrame(parent, 0, Qt::WRepaintNoErase)
 {
     d = new PreviewWidgetPriv;
-    setMinimumSize(QSize(484, 364));
+    setFrameStyle(QFrame::GroupBoxPanel|QFrame::Plain); 
+    setMargin(0); 
+    setLineWidth(1); 
+
+    setMinimumSize(QSize(400, 300));
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
 
-    d->pix = new QPixmap(484,364);
+    d->pix = new QPixmap(400, 300);
     d->pix->fill(Qt::black);
 
     d->timer = new QTimer(this);
@@ -101,21 +107,33 @@ void PreviewWidget::load(const QString& file)
     }
     else 
     {
-        setText(i18n( "Failed to load image after processing" ));
+        setInfo(i18n( "Failed to load image after processing" ));
         return;
     }
 
     update();
 }
 
-void PreviewWidget::setText(const QString& text, const QColor& color)
+void PreviewWidget::setInfo(const QString& text, const QColor& color, const QPixmap& preview)
 {
-    d->text = text;
+    d->text    = text;
+    d->preview = preview;
     d->pix->fill(Qt::black);
     QPainter p(d->pix);
     p.setPen(QPen(color));
-    p.drawText(0, 0, d->pix->width(), d->pix->height(),
-               Qt::AlignCenter|Qt::WordBreak, text);
+
+    if (!d->preview.isNull())
+    {
+        p.drawPixmap(d->pix->width()/2-d->preview.width()/2, d->pix->height()/4-d->preview.height()/2, 
+                     d->preview, 0, 0, d->preview.width(), d->preview.height());
+        p.drawText(0, d->pix->height()/2, d->pix->width(), d->pix->height()/2,
+                   Qt::AlignCenter|Qt::WordBreak, d->text);
+    }
+    else
+    {
+        p.drawText(0, 0, d->pix->width(), d->pix->height(),
+                   Qt::AlignCenter|Qt::WordBreak, d->text);
+    }
     p.end();
     update();
 }
@@ -141,15 +159,27 @@ void PreviewWidget::slotResize()
     {
         QPainter p(d->pix);
         p.setPen(QPen(Qt::white));
-        p.drawText(0, 0, d->pix->width(), d->pix->height(),
-                   Qt::AlignCenter|Qt::WordBreak, d->text);
+
+        if (!d->preview.isNull())
+        {
+            p.drawPixmap(d->pix->width()/2-d->preview.width()/2, d->pix->height()/4-d->preview.height()/2, 
+                        d->preview, 0, 0, d->preview.width(), d->preview.height());
+            p.drawText(0, d->pix->height()/2, d->pix->width(), d->pix->height()/2,
+                    Qt::AlignCenter|Qt::WordBreak, d->text);
+        }
+        else
+        {
+            p.drawText(0, 0, d->pix->width(), d->pix->height(),
+                    Qt::AlignCenter|Qt::WordBreak, d->text);
+        }
+
         p.end();
     }
     else 
     {
         if (!d->image.isNull()) 
         {
-            QImage img = d->image.scale(width(),height(),QImage::ScaleMin);
+            QImage img = d->image.scale(width(),height(), QImage::ScaleMin);
             int x = d->pix->width()/2 - img.width()/2;
             int y = d->pix->height()/2 - img.height()/2;
 
