@@ -1,23 +1,24 @@
 /* ============================================================
- * Authors: Renchi Raju <renchi@pooh.tam.uiuc.edu>
- *          Gilles Caulier <caulier dot gilles at kdemail dot net>
- * Date   : 2003-10-22
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2003-10-22
  * Description : Raw converter single dialog
  *
- * Copyright 2003-2005 by Renchi Raju
- * Copyright 2006 by Gilles Caulier
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
+ * either version 2, or (at your option) any later version.
+ * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * ============================================================ */
 
 // C Ansi includes.
@@ -29,6 +30,10 @@ extern "C"
 #include <unistd.h>
 }
 
+// C++ includes.
+
+#include <cstdio> 
+
 // Qt includes.
 
 #include <qtimer.h>
@@ -37,6 +42,7 @@ extern "C"
 #include <qlayout.h>
 #include <qtooltip.h>
 #include <qfileinfo.h>
+#include <qgroupbox.h>
 #include <qevent.h>
 #include <qpushbutton.h>
 #include <qfile.h>
@@ -55,13 +61,16 @@ extern "C"
 #include <kstandarddirs.h>
 #include <kdebug.h>
 
+// LibKDcraw includes.
+
+#include <libkdcraw/dcrawsettingswidget.h>
+
 // Local includes.
 
 #include "kpaboutdata.h"
 #include "pluginsversion.h"
 #include "previewwidget.h"
-#include "dcrawiface.h"
-#include "dcrawsettingswidget.h"
+#include "rawdecodingiface.h"
 #include "savesettingswidget.h"
 #include "actionthread.h"
 #include "singledialog.h"
@@ -70,7 +79,7 @@ extern "C"
 namespace KIPIRawConverterPlugin
 {
 
-SingleDialog::SingleDialog(const QString& file, QWidget */*parent*/, const QString& dcrawVersion)
+SingleDialog::SingleDialog(const QString& file, QWidget */*parent*/)
             : KDialogBase(0, 0, false, i18n("Raw Image Converter"),
                           Help|Default|User1|User2|User3|Close, Close, true,
                           i18n("&Preview"), i18n("Con&vert"), i18n("&Abort"))
@@ -80,7 +89,7 @@ SingleDialog::SingleDialog(const QString& file, QWidget */*parent*/, const QStri
     
     QWidget *page = new QWidget( this );
     setMainWidget( page );
-    QGridLayout *mainLayout = new QGridLayout(page, 3, 1, 0, marginHint());
+    QGridLayout *mainLayout = new QGridLayout(page, 3, 1, 0, spacingHint());
 
     // --------------------------------------------------------------
 
@@ -107,23 +116,16 @@ SingleDialog::SingleDialog(const QString& file, QWidget */*parent*/, const QStri
 
     // --------------------------------------------------------------
 
-    QGroupBox *lbox = new QGroupBox(i18n("Image Preview"), page);
-    lbox->setColumnLayout(0, Qt::Vertical);
-    lbox->layout()->setSpacing( spacingHint() );
-    lbox->layout()->setMargin( marginHint() );
-    QVBoxLayout* lboxLayout = new QVBoxLayout(lbox->layout());
-
-    m_previewWidget = new PreviewWidget(lbox);
-    lboxLayout->addWidget(m_previewWidget);
-
-    mainLayout->addMultiCellWidget(lbox, 1, 3, 0, 0);
+    m_previewWidget = new PreviewWidget(page);
+    mainLayout->addMultiCellWidget(m_previewWidget, 1, 3, 0, 0);
 
     // ---------------------------------------------------------------
 
-    m_decodingSettingsBox = new DcrawSettingsWidget(page, dcrawVersion);
+    m_rawSettingsGroup    = new QGroupBox(1, Qt::Vertical, i18n("RAW Decoding Settings"), page);
+    m_decodingSettingsBox = new KDcrawIface::DcrawSettingsWidget(m_rawSettingsGroup, false, true, true);
     m_saveSettingsBox     = new SaveSettingsWidget(page);
 
-    mainLayout->addMultiCellWidget(m_decodingSettingsBox, 1, 1, 1, 1);
+    mainLayout->addMultiCellWidget(m_rawSettingsGroup, 1, 1, 1, 1);
     mainLayout->addMultiCellWidget(m_saveSettingsBox, 2, 2, 1, 1);
 
     mainLayout->setColStretch(0, 10);
@@ -132,27 +134,24 @@ SingleDialog::SingleDialog(const QString& file, QWidget */*parent*/, const QStri
     // ---------------------------------------------------------------
     // About data and help button.
 
-    QPushButton *helpButton = actionButton( Help );
-
-    m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("Raw Image Converter"),
+    m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("RAW Image Converter"),
                                            NULL,
                                            KAboutData::License_GPL,
-                                           I18N_NOOP("A Kipi plugin for Raw image conversion\n"
-                                                     "This plugin uses the Dave Coffin Raw photo "
-                                                     "decoder program \"dcraw\""),
+                                           I18N_NOOP("A Kipi plugin to convert Raw images\n"
+                                                     "Using KDcraw library"),
                                            "(c) 2003-2005, Renchi Raju\n"
-                                           "(c) 2006, Gilles Caulier");
+                                           "(c) 2006-2007, Gilles Caulier");
 
     m_about->addAuthor("Renchi Raju", I18N_NOOP("Original author"),
                        "renchi@pooh.tam.uiuc.edu");
 
     m_about->addAuthor("Gilles Caulier", I18N_NOOP("Maintainer"),
-                       "caulier dot gilles at kdemail dot net");
+                       "caulier dot gilles at gmail dot com");
 
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
     helpMenu->menu()->removeItemAt(0);
     helpMenu->menu()->insertItem(i18n("RAW Converter Handbook"), this, SLOT(slotHelp()), 0, -1, 0);
-    helpButton->setPopup( helpMenu->menu() );
+    actionButton(Help)->setPopup( helpMenu->menu() );
 
     // ---------------------------------------------------------------
 
@@ -163,13 +162,13 @@ SingleDialog::SingleDialog(const QString& file, QWidget */*parent*/, const QStri
     setButtonTip( User2, i18n("<p>Convert the Raw Image from current settings. "
                               "This uses a high-quality adaptive algorithm."));
 
-    setButtonTip( User3, i18n("<p>Abort the current RAW file conversion"));
+    setButtonTip( User3, i18n("<p>Abort the current Raw file conversion"));
     
     setButtonTip( Close, i18n("<p>Exit Raw Converter"));
 
     m_blinkPreviewTimer = new QTimer(this);
     m_blinkConvertTimer = new QTimer(this);
-    m_thread           = new ActionThread(this);
+    m_thread            = new ActionThread(this);
 
     // ---------------------------------------------------------------
 
@@ -226,23 +225,29 @@ void SingleDialog::readSettings()
     m_decodingSettingsBox->setAutoColorBalance(config.readBoolEntry("Use Auto Color Balance", true));
     m_decodingSettingsBox->setFourColor(config.readBoolEntry("Four Color RGB", false));
     m_decodingSettingsBox->setUnclipColor(config.readNumEntry("Unclip Color", 0));
-    m_decodingSettingsBox->setSecondarySensor(config.readBoolEntry("Use Secondary Sensor", false));
-    m_decodingSettingsBox->setNoiseReduction(config.readBoolEntry("Use Noise Resuction", false));
+    m_decodingSettingsBox->setDontStretchPixels(config.readBoolEntry("Dont Stretch Pixels", false));
+    m_decodingSettingsBox->setNoiseReduction(config.readBoolEntry("Use Noise Reduction", false));
     m_decodingSettingsBox->setBrightness(config.readDoubleNumEntry("Brightness Multiplier", 1.0));
-    m_decodingSettingsBox->setSigmaDomain(config.readDoubleNumEntry("Sigma Domain", 2.0));
-    m_decodingSettingsBox->setSigmaRange(config.readDoubleNumEntry("Sigma Range", 4.0));
+    m_decodingSettingsBox->setUseBlackPoint(config.readBoolEntry("Use Black Point", false));
+    m_decodingSettingsBox->setBlackPoint(config.readNumEntry("Black Point", 0));
+    m_decodingSettingsBox->setNRThreshold(config.readNumEntry("NR Threshold", 100));
+    m_decodingSettingsBox->setUseColorMultipliers(config.readBoolEntry("Use Color Multipliers", false));
+    m_decodingSettingsBox->setcolorMultiplier1(config.readDoubleNumEntry("Color Multiplier1", 1.0));
+    m_decodingSettingsBox->setcolorMultiplier2(config.readDoubleNumEntry("Color Multiplier2", 1.0));
+    m_decodingSettingsBox->setcolorMultiplier3(config.readDoubleNumEntry("Color Multiplier3", 1.0));
+    m_decodingSettingsBox->setcolorMultiplier4(config.readDoubleNumEntry("Color Multiplier4", 1.0));
 
     m_decodingSettingsBox->setQuality(
-        (RawDecodingSettings::DecodingQuality)config.readNumEntry("Decoding Quality", 
-            (int)(RawDecodingSettings::BILINEAR))); 
+        (KDcrawIface::RawDecodingSettings::DecodingQuality)config.readNumEntry("Decoding Quality", 
+            (int)(KDcrawIface::RawDecodingSettings::BILINEAR))); 
 
     m_decodingSettingsBox->setOutputColorSpace(
-        (RawDecodingSettings::OutputColorSpace)config.readNumEntry("Output Color Space", 
-            (int)(RawDecodingSettings::SRGB))); 
+        (KDcrawIface::RawDecodingSettings::OutputColorSpace)config.readNumEntry("Output Color Space", 
+            (int)(KDcrawIface::RawDecodingSettings::SRGB))); 
 
     m_saveSettingsBox->setFileFormat(
-        (RawDecodingSettings::OutputFormat)config.readNumEntry("Output Format", 
-            (int)(RawDecodingSettings::PNG))); 
+        (SaveSettingsWidget::OutputFormat)config.readNumEntry("Output Format", 
+            (int)(SaveSettingsWidget::OUTPUT_PNG))); 
 
     m_saveSettingsBox->setConflictRule(
         (SaveSettingsWidget::ConflictRule)config.readNumEntry("Conflict",
@@ -260,13 +265,19 @@ void SingleDialog::saveSettings()
     config.writeEntry("Use Auto Color Balance", m_decodingSettingsBox->useAutoColorBalance());
     config.writeEntry("Four Color RGB", m_decodingSettingsBox->useFourColor());
     config.writeEntry("Unclip Color", m_decodingSettingsBox->unclipColor());
-    config.writeEntry("Use Secondary Sensor", m_decodingSettingsBox->useSecondarySensor());
-    config.writeEntry("Use Noise Resuction", m_decodingSettingsBox->useNoiseReduction());
+    config.writeEntry("Dont Stretch Pixels", m_decodingSettingsBox->useDontStretchPixels());
+    config.writeEntry("Use Noise Reduction", m_decodingSettingsBox->useNoiseReduction());
     config.writeEntry("Brightness Multiplier", m_decodingSettingsBox->brightness());
-    config.writeEntry("Sigma Domain", m_decodingSettingsBox->sigmaDomain());
-    config.writeEntry("Sigma Range", m_decodingSettingsBox->sigmaRange());
+    config.writeEntry("Use Black Point", m_decodingSettingsBox->useBlackPoint());
+    config.writeEntry("Black Point", m_decodingSettingsBox->blackPoint());
+    config.writeEntry("NR Threshold", m_decodingSettingsBox->NRThreshold());
     config.writeEntry("Decoding Quality", (int)m_decodingSettingsBox->quality());
     config.writeEntry("Output Color Space", (int)m_decodingSettingsBox->outputColorSpace());
+    config.writeEntry("Use Color Multipliers", m_decodingSettingsBox->useColorMultipliers());
+    config.writeEntry("Color Multiplier1", m_decodingSettingsBox->colorMultiplier1());
+    config.writeEntry("Color Multiplier2", m_decodingSettingsBox->colorMultiplier2());
+    config.writeEntry("Color Multiplier3", m_decodingSettingsBox->colorMultiplier3());
+    config.writeEntry("Color Multiplier4", m_decodingSettingsBox->colorMultiplier4());
 
     config.writeEntry("Output Format", (int)m_saveSettingsBox->fileFormat());
     config.writeEntry("Conflict", (int)m_saveSettingsBox->conflictRule());
@@ -283,20 +294,26 @@ void SingleDialog::slotHelp()
 // 'Preview' dialog button.
 void SingleDialog::slotUser1()
 {
-    RawDecodingSettings rawDecodingSettings;
-    rawDecodingSettings.cameraColorBalance      = m_decodingSettingsBox->useCameraWB();
-    rawDecodingSettings.automaticColorBalance   = m_decodingSettingsBox->useAutoColorBalance();
-    rawDecodingSettings.RGBInterpolate4Colors   = m_decodingSettingsBox->useFourColor();
-    rawDecodingSettings.unclipColors            = m_decodingSettingsBox->unclipColor();
-    rawDecodingSettings.SuperCCDsecondarySensor = m_decodingSettingsBox->useSecondarySensor();
-    rawDecodingSettings.enableNoiseReduction    = m_decodingSettingsBox->useNoiseReduction();
-    rawDecodingSettings.brightness              = m_decodingSettingsBox->brightness();
-    rawDecodingSettings.NRSigmaDomain           = m_decodingSettingsBox->sigmaDomain();
-    rawDecodingSettings.NRSigmaRange            = m_decodingSettingsBox->sigmaRange();
-    rawDecodingSettings.RAWQuality              = m_decodingSettingsBox->quality();
-    rawDecodingSettings.outputColorSpace        = m_decodingSettingsBox->outputColorSpace();
+    KDcrawIface::RawDecodingSettings rawDecodingSettings;
+    rawDecodingSettings.cameraColorBalance         = m_decodingSettingsBox->useCameraWB();
+    rawDecodingSettings.automaticColorBalance      = m_decodingSettingsBox->useAutoColorBalance();
+    rawDecodingSettings.RGBInterpolate4Colors      = m_decodingSettingsBox->useFourColor();
+    rawDecodingSettings.unclipColors               = m_decodingSettingsBox->unclipColor();
+    rawDecodingSettings.DontStretchPixels          = m_decodingSettingsBox->useDontStretchPixels();
+    rawDecodingSettings.enableNoiseReduction       = m_decodingSettingsBox->useNoiseReduction();
+    rawDecodingSettings.brightness                 = m_decodingSettingsBox->brightness();
+    rawDecodingSettings.enableBlackPoint           = m_decodingSettingsBox->useBlackPoint();
+    rawDecodingSettings.blackPoint                 = m_decodingSettingsBox->blackPoint();
+    rawDecodingSettings.NRThreshold                = m_decodingSettingsBox->NRThreshold();
+    rawDecodingSettings.RAWQuality                 = m_decodingSettingsBox->quality();
+    rawDecodingSettings.outputColorSpace           = m_decodingSettingsBox->outputColorSpace();
+    rawDecodingSettings.enableColorMultipliers     = m_decodingSettingsBox->useColorMultipliers();
+    rawDecodingSettings.colorBalanceMultipliers[0] = m_decodingSettingsBox->colorMultiplier1();
+    rawDecodingSettings.colorBalanceMultipliers[1] = m_decodingSettingsBox->colorMultiplier2();
+    rawDecodingSettings.colorBalanceMultipliers[2] = m_decodingSettingsBox->colorMultiplier3();
+    rawDecodingSettings.colorBalanceMultipliers[3] = m_decodingSettingsBox->colorMultiplier4();
     
-    m_thread->setRawDecodingSettings(rawDecodingSettings);
+    m_thread->setRawDecodingSettings(rawDecodingSettings, SaveSettingsWidget::OUTPUT_PPM);
     m_thread->processHalfRawFile(KURL(m_inputFile));
     if (!m_thread->running())
         m_thread->start();
@@ -305,21 +322,26 @@ void SingleDialog::slotUser1()
 // 'Convert' dialog button.
 void SingleDialog::slotUser2()
 {
-    RawDecodingSettings rawDecodingSettings;
-    rawDecodingSettings.cameraColorBalance      = m_decodingSettingsBox->useCameraWB();
-    rawDecodingSettings.automaticColorBalance   = m_decodingSettingsBox->useAutoColorBalance();
-    rawDecodingSettings.RGBInterpolate4Colors   = m_decodingSettingsBox->useFourColor();
-    rawDecodingSettings.unclipColors            = m_decodingSettingsBox->unclipColor();
-    rawDecodingSettings.SuperCCDsecondarySensor = m_decodingSettingsBox->useSecondarySensor();
-    rawDecodingSettings.enableNoiseReduction    = m_decodingSettingsBox->useNoiseReduction();
-    rawDecodingSettings.brightness              = m_decodingSettingsBox->brightness();
-    rawDecodingSettings.NRSigmaDomain           = m_decodingSettingsBox->sigmaDomain();
-    rawDecodingSettings.NRSigmaRange            = m_decodingSettingsBox->sigmaRange();
-    rawDecodingSettings.RAWQuality              = m_decodingSettingsBox->quality();
-    rawDecodingSettings.outputFileFormat        = m_saveSettingsBox->fileFormat();
-    rawDecodingSettings.outputColorSpace        = m_decodingSettingsBox->outputColorSpace();
+    KDcrawIface::RawDecodingSettings rawDecodingSettings;
+    rawDecodingSettings.cameraColorBalance         = m_decodingSettingsBox->useCameraWB();
+    rawDecodingSettings.automaticColorBalance      = m_decodingSettingsBox->useAutoColorBalance();
+    rawDecodingSettings.RGBInterpolate4Colors      = m_decodingSettingsBox->useFourColor();
+    rawDecodingSettings.unclipColors               = m_decodingSettingsBox->unclipColor();
+    rawDecodingSettings.DontStretchPixels          = m_decodingSettingsBox->useDontStretchPixels();
+    rawDecodingSettings.enableNoiseReduction       = m_decodingSettingsBox->useNoiseReduction();
+    rawDecodingSettings.brightness                 = m_decodingSettingsBox->brightness();
+    rawDecodingSettings.enableBlackPoint           = m_decodingSettingsBox->useBlackPoint();
+    rawDecodingSettings.blackPoint                 = m_decodingSettingsBox->blackPoint();
+    rawDecodingSettings.NRThreshold                = m_decodingSettingsBox->NRThreshold();
+    rawDecodingSettings.RAWQuality                 = m_decodingSettingsBox->quality();
+    rawDecodingSettings.outputColorSpace           = m_decodingSettingsBox->outputColorSpace();
+    rawDecodingSettings.enableColorMultipliers     = m_decodingSettingsBox->useColorMultipliers();
+    rawDecodingSettings.colorBalanceMultipliers[0] = m_decodingSettingsBox->colorMultiplier1();
+    rawDecodingSettings.colorBalanceMultipliers[1] = m_decodingSettingsBox->colorMultiplier2();
+    rawDecodingSettings.colorBalanceMultipliers[2] = m_decodingSettingsBox->colorMultiplier3();
+    rawDecodingSettings.colorBalanceMultipliers[3] = m_decodingSettingsBox->colorMultiplier4();
 
-    m_thread->setRawDecodingSettings(rawDecodingSettings);
+    m_thread->setRawDecodingSettings(rawDecodingSettings, m_saveSettingsBox->fileFormat());
     m_thread->processRawFile(KURL(m_inputFile));
     if (!m_thread->running())
         m_thread->start();
@@ -333,14 +355,14 @@ void SingleDialog::slotUser3()
 
 void SingleDialog::slotIdentify()
 {
-    m_thread->identifyRawFile(KURL(m_inputFile));
+    m_thread->identifyRawFile(KURL(m_inputFile), true);
     if (!m_thread->running())
         m_thread->start();
 }
 
 void SingleDialog::busy(bool val)
 {   
-    m_decodingSettingsBox->setEnabled(!val);
+    m_rawSettingsGroup->setEnabled(!val);
     m_saveSettingsBox->setEnabled(!val);
     enableButton (User1, !val);
     enableButton (User2, !val);
@@ -348,9 +370,9 @@ void SingleDialog::busy(bool val)
     enableButton (Close, !val);
 }
 
-void SingleDialog::identified(const QString&, const QString& identity)
+void SingleDialog::identified(const QString&, const QString& identity, const QPixmap& preview)
 {
-    m_previewWidget->setText(m_inputFileName + QString(" : ") + identity);
+    m_previewWidget->setInfo(m_inputFileName + QString(" :\n") + identity, Qt::white, preview);
 }
 
 void SingleDialog::previewing(const QString&)
@@ -365,13 +387,14 @@ void SingleDialog::previewed(const QString&, const QString& tmpFile)
     m_previewWidget->unsetCursor();
     m_blinkPreviewTimer->stop();
     m_previewWidget->load(tmpFile);
+    ::remove(QFile::encodeName(tmpFile));
 }
 
 void SingleDialog::previewFailed(const QString&)
 {
     m_previewWidget->unsetCursor();
     m_blinkPreviewTimer->stop();
-    m_previewWidget->setText(i18n("Failed to generate preview"), Qt::red);
+    m_previewWidget->setInfo(i18n("Failed to generate preview"), Qt::red);
 }
 
 void SingleDialog::processing(const QString&)
@@ -391,16 +414,16 @@ void SingleDialog::processed(const QString&, const QString& tmpFile)
 
     switch(m_saveSettingsBox->fileFormat())
     {
-        case RawDecodingSettings::JPEG:
+        case SaveSettingsWidget::OUTPUT_JPEG:
             ext = "jpg";
             break;
-        case RawDecodingSettings::TIFF:
+        case SaveSettingsWidget::OUTPUT_TIFF:
             ext = "tif";
             break;
-        case RawDecodingSettings::PPM:
+        case SaveSettingsWidget::OUTPUT_PPM:
             ext = "ppm";
             break;
-        case RawDecodingSettings::PNG:
+        case SaveSettingsWidget::OUTPUT_PNG:
             ext = "png";
             break;
     }
@@ -450,7 +473,7 @@ void SingleDialog::processingFailed(const QString&)
 {
     m_previewWidget->unsetCursor();
     m_blinkConvertTimer->stop();
-    m_previewWidget->setText(i18n("Failed to convert Raw image"), Qt::red);
+    m_previewWidget->setInfo(i18n("Failed to convert Raw image"), Qt::red);
 }
 
 void SingleDialog::slotPreviewBlinkTimerDone()
@@ -458,9 +481,9 @@ void SingleDialog::slotPreviewBlinkTimerDone()
     QString preview = i18n("Generating Preview...");
 
     if (m_previewBlink)
-        m_previewWidget->setText(preview, Qt::green);
+        m_previewWidget->setInfo(preview, Qt::green);
     else
-        m_previewWidget->setText(preview, Qt::darkGreen);
+        m_previewWidget->setInfo(preview, Qt::darkGreen);
 
     m_previewBlink = !m_previewBlink;
     m_blinkPreviewTimer->start(200);
@@ -471,9 +494,9 @@ void SingleDialog::slotConvertBlinkTimerDone()
     QString convert = i18n("Converting Raw Image...");
 
     if (m_convertBlink)
-        m_previewWidget->setText(convert, Qt::green);
+        m_previewWidget->setInfo(convert, Qt::green);
     else
-        m_previewWidget->setText(convert, Qt::darkGreen);
+        m_previewWidget->setInfo(convert, Qt::darkGreen);
 
     m_convertBlink = !m_convertBlink;
     m_blinkConvertTimer->start(200);
@@ -492,7 +515,7 @@ void SingleDialog::customEvent(QCustomEvent *event)
     {
         switch (d->action) 
         {
-            case(IDENTIFY): 
+            case(IDENTIFY_FULL): 
                 break;
             case(PREVIEW):
             {
@@ -519,7 +542,7 @@ void SingleDialog::customEvent(QCustomEvent *event)
         {
             switch (d->action) 
             {
-                case(IDENTIFY): 
+                case(IDENTIFY_FULL): 
                     break;
                 case(PREVIEW):
                 {
@@ -544,9 +567,10 @@ void SingleDialog::customEvent(QCustomEvent *event)
         {
             switch (d->action)
             {
-                case(IDENTIFY): 
+                case(IDENTIFY_FULL): 
                 {
-                    identified(d->filePath, d->message);
+                    QPixmap pix = QPixmap(d->image.scale(256, 256, QImage::ScaleMin));
+                    identified(d->filePath, d->message, pix);
                     busy(false);
                     break;
                 }
