@@ -1,10 +1,10 @@
 /* ============================================================
- * Authors: Gilles Caulier <caulier dot gilles at free.fr>
+ * Authors: Gilles Caulier <caulier dot gilles at gmail dot com>
  * Date   : 2003-10-01
  * Description : a kipi plugin to e-mailing images
  * 
- * Copyright 2003-2005 by Gilles Caulier
- * Copyright 2006 by Tom Albers
+ * Copyright 2003-2005 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright 2006 by Tom Albers <tomalbers at kde.nl>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -159,7 +159,7 @@ SendImagesDialog::SendImagesDialog(QWidget *parent, KIPI::Interface* interface,
                                            "(c) 2003-2005, Gilles Caulier");
 
     m_about->addAuthor("Gilles Caulier", I18N_NOOP("Author and maintainer"),
-                       "caulier dot gilles at kdemail dot net");
+                       "caulier dot gilles at gmail dot com");
 
     m_helpButton        = actionButton( Help );
     KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
@@ -210,6 +210,11 @@ void SendImagesDialog::readSettings(void)
         m_addComments->setChecked( true );
     else
         m_addComments->setChecked( false );
+
+    if (config.readEntry("Comment2ImageName", "true") == "true")
+        m_comment2ImageName->setChecked( true );
+    else
+        m_comment2ImageName->setChecked( false );
 }
 
 void SendImagesDialog::writeSettings(void)
@@ -225,7 +230,8 @@ void SendImagesDialog::writeSettings(void)
     config.writeEntry("ImageResize", m_imagesResize->currentItem());
     config.writeEntry("ImageCompression", m_imageCompression->value());
     config.writeEntry("ImageFormat", m_imagesFormat->currentText());
-    config.writeEntry("AttachmentLimit", m_attachmentlimit->value());	
+    config.writeEntry("AttachmentLimit", m_attachmentlimit->value());
+    config.writeEntry("Comment2ImageName", m_comment2ImageName->isChecked());
     config.sync();
 }
 
@@ -234,7 +240,7 @@ void SendImagesDialog::setupImagesList(void)
     QString whatsThis;
 
     page_setupImagesList = addPage(i18n("Images"),
-                                   i18n("Image List to Email"),
+                                   i18n("Images to EMail"),
                                    BarIcon("image", KIcon::SizeMedium));
 
     QVBoxLayout *vlay = new QVBoxLayout( page_setupImagesList, 0, spacingHint() );
@@ -252,9 +258,9 @@ void SendImagesDialog::setupImagesList(void)
     grid->addMultiCellWidget(m_ImagesFilesListBox, 0, 2, 0, 1);
 
     KButtonBox* imagesListButtonBox = new KButtonBox( m_groupBoxImageList, Vertical );
-    QPushButton* m_addImagesButton = imagesListButtonBox->addButton ( i18n( "&Add Images..." ) );
+    QPushButton* m_addImagesButton = imagesListButtonBox->addButton ( i18n( "&Add ..." ) );
     QWhatsThis::add( m_addImagesButton, i18n("<p>Add images to the list.") );
-    QPushButton* m_remImagesButton = imagesListButtonBox->addButton ( i18n( "&Remove Images" ));
+    QPushButton* m_remImagesButton = imagesListButtonBox->addButton ( i18n( "&Remove" ));
     QWhatsThis::add( m_remImagesButton, i18n("<p>Remove selected images from the list.") );
     imagesListButtonBox->layout();
     grid->addMultiCellWidget(imagesListButtonBox, 0, 1, 2, 2);
@@ -362,6 +368,7 @@ void SendImagesDialog::setupEmailOptions(void)
     m_mailAgentName = new QComboBox( false, page_setupEmailOptions );
     m_mailAgentName->insertItem( "Default" );
     m_mailAgentName->insertItem( "Balsa" );
+    m_mailAgentName->insertItem( "Claws Mail" );
     m_mailAgentName->insertItem( "Evolution" );
     m_mailAgentName->insertItem( "GmailAgent" );
     m_mailAgentName->insertItem( "KMail" );
@@ -374,6 +381,7 @@ void SendImagesDialog::setupEmailOptions(void)
     QWhatsThis::add( m_mailAgentName, i18n("<p>Select here your preferred external mail agent program."
                                            "These mail agent versions are supported:<p>"
                                            "<b>Balsa</b>: >= 2.x<p>"
+					   "<b>Claws Mail</b>: >= 2.6.1<p>"
                                            "<b>Evolution</b>: >= 1.4<p>"
                                            "<b>GmailAgent</b>: >= 0.2<p>"
                                            "<b>KMail</b>: >= 1.3<p>"
@@ -410,10 +418,12 @@ void SendImagesDialog::setupEmailOptions(void)
     QWhatsThis::add( m_addComments, i18n("<p>If you enable this option, all images comments and tags "
                                          "will be added as an attached file.") );
     vlay->addWidget( m_addComments );
+    m_comment2ImageName = new QCheckBox( i18n("Generate new filenames from image comments (if comment available)"), page_setupEmailOptions);
+    vlay->addWidget( m_comment2ImageName );
 
     //---------------------------------------------
 
-    QGroupBox * groupBox2 = new QGroupBox( i18n("Images Properties"), page_setupEmailOptions );
+    QGroupBox * groupBox2 = new QGroupBox( i18n("Image Properties"), page_setupEmailOptions );
     groupBox2->setColumnLayout(0, Qt::Vertical );
     groupBox2->layout()->setSpacing( 6 );
     groupBox2->layout()->setMargin( 11 );
@@ -422,7 +432,7 @@ void SendImagesDialog::setupEmailOptions(void)
     QVBoxLayout * groupBox2Layout = new QVBoxLayout( groupBox2->layout() );
     groupBox2Layout->setAlignment( Qt::AlignTop );
 
-    m_changeImagesProp = new QCheckBox(i18n("Change properties of images"), groupBox2);
+    m_changeImagesProp = new QCheckBox(i18n("Adjust image properties"), groupBox2);
     QWhatsThis::add( m_changeImagesProp, i18n("<p>If you enable this option, "
                      "all images to send can be resized and recompressed.") );
     m_changeImagesProp->setChecked( true );
@@ -458,7 +468,7 @@ void SendImagesDialog::setupEmailOptions(void)
 		     .arg(i18n("huge - for printing (1600 pixels)"));
     QWhatsThis::add( m_imagesResize, whatsThis );
 
-    m_labelImageSize = new QLabel( i18n("New images size:"), groupBox2);
+    m_labelImageSize = new QLabel( i18n("Sent image size:"), groupBox2);
     hlay12->addWidget( m_labelImageSize );
     m_labelImageSize->setBuddy( m_imagesResize );
     hlay12->addStretch( 1 );
@@ -468,7 +478,7 @@ void SendImagesDialog::setupEmailOptions(void)
 
     m_imageCompression = new KIntNumInput(75, groupBox2);
     m_imageCompression->setRange(1, 100, 1, true );
-    m_imageCompression->setLabel( i18n("New images compression:") );
+    m_imageCompression->setLabel( i18n("Sent image quality level:") );
     groupBox2Layout->addWidget( m_imageCompression );
     whatsThis = i18n("<p>The new compression value of images to send:<p>");
     whatsThis = whatsThis + i18n("<b>1</b>: very high compression<p>"
@@ -499,7 +509,7 @@ void SendImagesDialog::setupEmailOptions(void)
                 "and chromaticity data for improved color matching on heterogeneous platforms.");
     QWhatsThis::add( m_imagesFormat, whatsThis );
 
-    m_labelImageFormat = new QLabel(i18n("Images file format:"), groupBox2);
+    m_labelImageFormat = new QLabel(i18n("Image file format:"), groupBox2);
     hlay13->addWidget(m_labelImageFormat);
     m_labelImageFormat->setBuddy(m_imagesFormat);
     hlay13->addStretch(1);
@@ -510,7 +520,7 @@ void SendImagesDialog::setupEmailOptions(void)
 
     m_attachmentlimit = new KIntNumInput(17, page_setupEmailOptions);
     m_attachmentlimit->setRange(1, 50, 1, true );
-    m_attachmentlimit->setLabel( i18n("Maximum Email Size:"));
+    m_attachmentlimit->setLabel( i18n("Maximum Email size limit:"));
     m_attachmentlimit->setSuffix(i18n("MB"));
     vlay->addWidget( m_attachmentlimit );
 		    
