@@ -4,7 +4,7 @@
  * Date  : 2003-01-31
  * Description :
  *
- * Copyright 2003 by Renchi Raju
+ * Copyright 2003 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
 
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,9 +22,14 @@
 #ifndef PLUGIN_SLIDESHOW_H
 #define PLUGIN_SLIDESHOW_H
 
+// KDE includes
+
+#include <kurl.h>
+
 // libKIPI includes.
 
 #include <libkipi/plugin.h>
+#include <libkipi/interface.h>
 
 class KAction;
 
@@ -53,9 +58,11 @@ private slots:
 
 private:
 
-    KAction *m_actionSlideShow;
+    KAction*         m_actionSlideShow;
+    KIPI::Interface* m_interface;
+    KURL::List*      m_urlList;
 
-    bool m_ImagesHasComments;
+    bool m_imagesHasComments;
 };
 
 #endif
