@@ -4,7 +4,7 @@
  * Date  : 2004-01-19
  * Description : 
  * 
- * Copyright 2004 by Renchi Raju
+ * Copyright 2004 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
  
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -22,6 +22,8 @@
 #ifndef SLIDESHOWGL_H
 #define SLIDESHOWGL_H
 
+#include <kconfig.h>
+
 #include <qvaluelist.h>
 #include <qstringlist.h>
 #include <qpair.h>
@@ -43,10 +45,7 @@ class SlideShowGL : public QGLWidget
 public:
 
     SlideShowGL(const QValueList<QPair<QString, int> >& fileList,
-                const QStringList& commentsList, bool ImagesHasComments,
-                int delay, bool printName, bool printComments, bool loop,
-                const QString& effectName,
-                const QFont& commentsFont, uint commentsFontColor, uint commentsBgColor, int commentsLinesLength);
+                const QStringList& commentsList, bool ImagesHasComments);
     ~SlideShowGL();
 
     void registerEffects();
@@ -62,59 +61,65 @@ protected:
     
     void mousePressEvent(QMouseEvent *event);
     void mouseMoveEvent(QMouseEvent *);
+    void wheelEvent(QWheelEvent *e);
     void keyPressEvent(QKeyEvent *event);
         
 private:
 
     // config ------------------
 
-    int         delay_;
-    QString     effectName_;
-    bool        loop_;
-    bool        printName_;
-    bool        printComments_;
+    KConfig*    m_config;
     
-    bool        ImagesHasComments_;
+    int         m_delay;
+    QString     m_effectName;
+    bool        m_loop;
+    bool        m_printName;
+    bool        m_printProgress;
+    bool        m_printComments;
     
-    QFont       commentsFont_;
-    uint        commentsFontColor_;
-    uint        commentsBgColor_;
-    int         commentsLinesLength_;
+    bool        m_imagesHasComments;
+    
+    QFont*      m_commentsFont;
+    uint        m_commentsFontColor;
+    uint        m_commentsBgColor;
+    int         m_commentsLinesLength;
+    
+    bool        m_enableMouseWheel;
 
     // -------------------------
     
     typedef void (SlideShowGL::*EffectMethod)();
-    QMap<QString, EffectMethod> Effects;
+    QMap<QString, EffectMethod> m_effects;
 
-    QValueList<QPair<QString, int> >  fileList_;
-    QStringList  commentsList_;
-    QTimer*      timer_;
-    int          fileIndex_;
+    QValueList<QPair<QString, int> >  m_fileList;
+    QStringList  m_commentsList;
+    QTimer*      m_timer;
+    int          m_fileIndex;
 
-    GLuint       texture_[2];
-    bool         tex1First_;
-    int          curr_;
+    GLuint       m_texture[2];
+    bool         m_tex1First;
+    int          m_curr;
     
-    int          width_;
-    int          height_;
+    int          m_width;
+    int          m_height;
 
-    EffectMethod effect_;
-    bool         effectRunning_;
-    int          timeout_;
-    bool         random_;
-    bool         endOfShow_;
+    EffectMethod m_effect;
+    bool         m_effectRunning;
+    int          m_timeout;
+    bool         m_random;
+    bool         m_endOfShow;
 
     int          m_i;
     int          m_dir;
     float        m_points[40][40][3];
 
-    ToolBar*     toolBar_;
-    QTimer*      mouseMoveTimer_;
+    ToolBar*     m_toolBar;
+    QTimer*      m_mouseMoveTimer;
 
-    int          deskX_;
-    int          deskY_;
-    int          deskWidth_;
-    int          deskHeight_;
+    int          m_deskX;
+    int          m_deskY;
+    int          m_deskWidth;
+    int          m_deskHeight;
     
 private:
 
@@ -126,8 +131,11 @@ private:
     EffectMethod  getRandomEffect();
     void          showEndOfShow();
     void          printFilename(QImage& layer);
+    void          printProgress(QImage& layer);
     void          printComments(QImage& layer);
     
+    void          readSettings();
+    
     void          effectNone();
     void          effectBlend();
     void          effectFade();
