@@ -1,27 +1,36 @@
 /* ============================================================
- * Authors: Jesper K. Pedersen <blackie@kde.org>
- *          Gilles Caulier <caulier dot gilles at kdemail dot net>
- * Date   : 2004-05-16
+ *
+ * This file is a part of kipi-plugins project
+ * http://www.kipi-plugins.org
+ *
+ * Date        : 2004-05-16
  * Description : a plugin to set time stamp of picture files.
  *
- * Copyright 2003-2005 by Jesper Pedersen
- * Copyright 2006 by Gilles Caulier
+ * Copyright (C) 2003-2005 by Jesper Pedersen <blackie@kde.org>
+ * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
+ * either version 2, or (at your option) any later version.
+ * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
+ * 
  * ============================================================ */
 
+// C Ansi includes.
+
+extern "C"
+{
+#include <utime.h>
+}
+
 // Qt includes.
 
+#include <qtooltip.h>
 #include <qlayout.h>
 #include <qlabel.h>
 #include <qvbuttongroup.h>
@@ -30,13 +39,16 @@
 #include <qhbox.h>
 #include <qcheckbox.h>
 #include <qradiobutton.h>
+#include <qfile.h>
 #include <qspinbox.h>
 #include <qgrid.h>
 #include <qpushbutton.h>
 #include <qframe.h>
+#include <qtoolbutton.h>
 
 // KDE includes.
 
+#include <kiconloader.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <kapplication.h>
@@ -54,11 +66,14 @@
 #include <libkipi/interface.h>
 #include <libkipi/imageinfo.h>
 
+// LibKExiv2 includes. 
+
+#include <libkexiv2/kexiv2.h>
+
 // Local includes.
 
 #include "kpaboutdata.h"
 #include "pluginsversion.h"
-#include "exiv2iface.h"
 #include "timeadjustdialog.h"
 #include "timeadjustdialog.moc"
 
@@ -92,6 +107,7 @@ public:
         dateCreatedSel    = 0;
         interface         = 0;
         about             = 0;
+        todayBtn          = 0;
     }
 
     QRadioButton             *add;
@@ -99,6 +115,8 @@ public:
     QRadioButton             *exif;
     QRadioButton             *custom;
 
+    QToolButton              *todayBtn;
+
     QCheckBox                *syncEXIFDateCheck;
     QCheckBox                *syncIPTCDateCheck;
 
@@ -145,11 +163,11 @@ TimeAdjustDialog::TimeAdjustDialog(KIPI::Interface* interface, QWidget* parent)
                                            "(c) 2003-2005, Jesper K. Pedersen\n"
                                            "(c) 2006, Gilles Caulier");
 
-    d->about->addAuthor("Jesper K. Pedersen", I18N_NOOP("Author and maintainer"),
-                       "blackie@kde.org");
+    d->about->addAuthor("Jesper K. Pedersen", I18N_NOOP("Author"),
+                        "blackie@kde.org");
 
-    d->about->addAuthor("Gilles Caulier", I18N_NOOP("Developper"),
-                       "caulier dot gilles at kdemail dot net");
+    d->about->addAuthor("Gilles Caulier", I18N_NOOP("Developper and maintainer"),
+                        "caulier dot gilles at gmail dot com");
 
     QPushButton *helpButton = actionButton(Help);
     KHelpMenu* helpMenu = new KHelpMenu(this, d->about, false);
@@ -183,25 +201,29 @@ TimeAdjustDialog::TimeAdjustDialog(KIPI::Interface* interface, QWidget* parent)
     // -- Adjustment type ------------------------------------------------------------
 
     QVGroupBox *adjGB = new QVGroupBox(i18n("Adjustment Type"), plainPage());
-    d->adjustTypeGrp   = new QButtonGroup(1, Qt::Horizontal, adjGB);
-    d->add             = new QRadioButton(i18n("Add"), d->adjustTypeGrp);
-    d->subtract        = new QRadioButton(i18n("Subtract"), d->adjustTypeGrp);
-    d->exif            = new QRadioButton(i18n("Set file date to EXIF/IPTC creation date"), d->adjustTypeGrp);
-    d->custom          = new QRadioButton(i18n("Custom date"), d->adjustTypeGrp);
+    d->adjustTypeGrp  = new QButtonGroup(1, Qt::Horizontal, adjGB);
+    d->add            = new QRadioButton(i18n("Add"), d->adjustTypeGrp);
+    d->subtract       = new QRadioButton(i18n("Subtract"), d->adjustTypeGrp);
+    d->exif           = new QRadioButton(i18n("Set file date to EXIF/IPTC creation date"), d->adjustTypeGrp);
+    d->custom         = new QRadioButton(i18n("Custom date"), d->adjustTypeGrp);
 
     d->adjustTypeGrp->setFrameStyle(QFrame::NoFrame);
     d->adjustTypeGrp->setInsideMargin(0); 
     d->adjustTypeGrp->setRadioButtonExclusive(true);
 
     QHBox *hbox       = new QHBox(d->adjustTypeGrp);
-    QLabel *space     = new QLabel(hbox);
+    QLabel *space1     = new QLabel(hbox);
+    space1->setFixedWidth(15);
     d->dateCreatedSel = new KDateTimeWidget(hbox);
+    QLabel *space2     = new QLabel(hbox);
+    space2->setFixedWidth(15);
+    d->todayBtn       = new QToolButton(hbox);   
+    d->todayBtn->setIconSet(SmallIcon("today"));
+    QToolTip::add(d->todayBtn, i18n("Reset to current date"));
     new QLabel(hbox);
-    space->setFixedWidth(15);
-    d->dateCreatedSel->setDateTime(QDateTime::currentDateTime());
     
-    d->syncEXIFDateCheck = new QCheckBox(i18n("Sync EXIF creation date"), d->adjustTypeGrp);
-    d->syncIPTCDateCheck = new QCheckBox(i18n("Sync IPTC creation date"), d->adjustTypeGrp);
+    d->syncEXIFDateCheck = new QCheckBox(i18n("Update Exif creation date"), d->adjustTypeGrp);
+    d->syncIPTCDateCheck = new QCheckBox(i18n("Update IPTC creation date"), d->adjustTypeGrp);
 
     vlay->addWidget(adjGB);
 
@@ -279,6 +301,9 @@ TimeAdjustDialog::TimeAdjustDialog(KIPI::Interface* interface, QWidget* parent)
     connect(d->years, SIGNAL( valueChanged( int ) ),
             this, SLOT( slotUpdateExample() ));
 
+    connect(d->todayBtn, SIGNAL(clicked()),
+            this, SLOT(slotResetDateToCurrent()));
+
     // -----------------------------------------------------------------------
 
     readSettings();
@@ -296,6 +321,11 @@ void TimeAdjustDialog::slotHelp()
     KApplication::kApplication()->invokeHelp("timeadjust", "kipi-plugins");
 }
 
+void TimeAdjustDialog::slotResetDateToCurrent()
+{
+    d->dateCreatedSel->setDateTime(QDateTime::currentDateTime());
+}
+
 void TimeAdjustDialog::closeEvent(QCloseEvent *e)
 {
     if (!e) return;
@@ -320,6 +350,9 @@ void TimeAdjustDialog::readSettings()
     if (adjType == 2) d->exif->setChecked(true);
     if (adjType == 3) d->custom->setChecked(true);
 
+    QDateTime current = QDateTime::currentDateTime();
+    d->dateCreatedSel->setDateTime(config.readDateTimeEntry("Custom Date", &current));
+
     d->syncEXIFDateCheck->setChecked(config.readBoolEntry("Sync EXIF Date", true));
     d->syncIPTCDateCheck->setChecked(config.readBoolEntry("Sync IPTC Date", true));
     resize(configDialogSize(config, QString("Time Adjust Dialog")));
@@ -336,6 +369,8 @@ void TimeAdjustDialog::saveSettings()
     if (d->custom->isChecked())   adjType = 3;
     config.writeEntry("Adjustment Type", adjType);
 
+    config.writeEntry("Custom Date", d->dateCreatedSel->dateTime());
+
     config.writeEntry("Sync EXIF Date", d->syncEXIFDateCheck->isChecked());
     config.writeEntry("Sync IPTC Date", d->syncIPTCDateCheck->isChecked());
     saveDialogSize(config, QString("Time Adjust Dialog"));
@@ -385,12 +420,12 @@ void TimeAdjustDialog::setImages(const KURL::List& images)
 
 void TimeAdjustDialog::slotUpdateExample()
 {
-    QString oldDate = d->exampleDate.toString();
+    QString oldDate = d->exampleDate.toString(Qt::LocalDate);
     QDateTime date  = updateTime(KURL(), d->exampleDate);
-    QString newDate = date.toString();
+    QString newDate = date.toString(Qt::LocalDate);
     d->exampleAdj->setText(i18n("<b>%1</b><br>would, for example, "
                                "change into<br><b>%2</b>")
-                          .arg(oldDate).arg(newDate));
+                           .arg(oldDate).arg(newDate));
 }
 
 void TimeAdjustDialog::slotAdjustmentTypeChanged()
@@ -398,6 +433,7 @@ void TimeAdjustDialog::slotAdjustmentTypeChanged()
     d->exampleBox->setEnabled(false);
     d->adjustValGrp->setEnabled(false);
     d->dateCreatedSel->setEnabled(false);
+    d->todayBtn->setEnabled(false);
     d->syncEXIFDateCheck->setEnabled(false);
     d->syncIPTCDateCheck->setEnabled(false);
 
@@ -411,6 +447,7 @@ void TimeAdjustDialog::slotAdjustmentTypeChanged()
     else if (d->custom->isChecked())
     {
         d->dateCreatedSel->setEnabled(true);
+        d->todayBtn->setEnabled(true);
         d->syncEXIFDateCheck->setEnabled(true);
         d->syncIPTCDateCheck->setEnabled(true);
     }
@@ -423,57 +460,67 @@ void TimeAdjustDialog::slotOk()
 
     for( KURL::List::ConstIterator it = d->images.begin(); it != d->images.end(); ++it )
     {
-        KURL url = *it;
-        bool ret = false;
-
+        KURL url             = *it;
         KIPI::ImageInfo info = d->interface->info(url);
         QDateTime dateTime   = info.time();
         dateTime             = updateTime(info.path(), info.time());
         info.setTime(dateTime);
 
-        if (!d->exif->isChecked())
+        // See B.K.O #138880: set the file acess and modification time.
+        struct utimbuf ut;
+        ut.modtime = dateTime.toTime_t();
+        ut.actime  = dateTime.toTime_t();
+        ::utime(QFile::encodeName(url.path()), &ut);
+
+        if (d->syncEXIFDateCheck->isChecked() || d->syncIPTCDateCheck->isChecked())
         {
-            if (d->syncEXIFDateCheck->isChecked() || d->syncIPTCDateCheck->isChecked())
+            bool ret = true;
+            if (!KExiv2Iface::KExiv2::isReadOnly(url.path()))
             {
-                if (!KIPIPlugins::Exiv2Iface::isReadOnly(url.path()))
+                KExiv2Iface::KExiv2 exiv2Iface;
+
+                ret &= exiv2Iface.load(url.path());
+                if (ret)
                 {
-                    ret = true;
-                    KIPIPlugins::Exiv2Iface exiv2Iface;
-    
-                    ret &= exiv2Iface.load(url.path());
-                    if (ret)
+                    if (d->syncEXIFDateCheck->isChecked())
                     {
-                        if (d->syncEXIFDateCheck->isChecked())
-                        {
-                            ret &= exiv2Iface.setExifTagString("Exif.Image.DateTime",
-                                dateTime.toString(QString("yyyy:MM:dd hh:mm:ss")).ascii());
-                        }
-            
-                        if (d->syncIPTCDateCheck->isChecked())
-                        {
-                            ret &= exiv2Iface.setIptcTagString("Iptc.Application2.DateCreated",
-                                dateTime.date().toString(Qt::ISODate));
-                            ret &= exiv2Iface.setIptcTagString("Iptc.Application2.TimeCreated",
-                                dateTime.time().toString(Qt::ISODate));
-                        }
+                        ret &= exiv2Iface.setExifTagString("Exif.Image.DateTime",
+                            dateTime.toString(QString("yyyy:MM:dd hh:mm:ss")).ascii());
+                    }
         
-                        ret &= exiv2Iface.save(url.path());
+                    if (d->syncIPTCDateCheck->isChecked())
+                    {
+                        ret &= exiv2Iface.setIptcTagString("Iptc.Application2.DateCreated",
+                            dateTime.date().toString(Qt::ISODate));
+                        ret &= exiv2Iface.setIptcTagString("Iptc.Application2.TimeCreated",
+                            dateTime.time().toString(Qt::ISODate));
+                    }
+    
+                    ret &= exiv2Iface.save(url.path());
+
+                    if (!ret)
+                    {
+                        kdDebug() << "Failed to save metadata to file " << url.fileName() << endl;
                     }
                 }
-        
-                if (!ret)
-                    errorFiles.append(url.fileName());
-                else 
-                    updatedURLs.append(url);
+                else
+                {
+                    kdDebug() << "Failed to load metadata from file " << url.fileName() << endl;
+                }
             }
-        }        
+    
+            if (!ret)
+                errorFiles.append(url.fileName());
+            else 
+                updatedURLs.append(url);
+        }
     }
 
     // We use kipi interface refreshImages() method to tell to host than 
     // metadata from pictures have changed and need to be re-read.
     d->interface->refreshImages(d->images);
 
-    if (!errorFiles.isEmpty())
+    if (!errorFiles.isEmpty() && (d->syncEXIFDateCheck->isChecked() || d->syncIPTCDateCheck->isChecked()))
     {
         KMessageBox::informationList(
                      kapp->activeWindow(),
@@ -494,7 +541,7 @@ QDateTime TimeAdjustDialog::updateTime(const KURL& url, const QDateTime& time) c
     }
     else if (d->exif->isChecked())
     {
-        KIPIPlugins::Exiv2Iface exiv2Iface;
+        KExiv2Iface::KExiv2 exiv2Iface;
         if ( !exiv2Iface.load(url.path()) )
             return time;
 
